class BDRouter(object):
    """
    A router to control all database operations on models in the
    auth application.
    """
    def db_for_read(self, model, **hints):
        """
        Attempts to read bydesign models go to bd.
        """
        if model._meta.app_label == 'bydesign':
            return 'bd'
        return None

    def db_for_write(self, model, **hints):
        """
        Attempts to write bydesign models go to 'bd'.
        """
        if model._meta.app_label == 'bydesign':
            return 'bd'
        return None

    def allow_relation(self, obj1, obj2, **hints):
        """
        Allow relations if both are in the bydesign app, but not if only one is.
        """
        if obj1._meta.app_label == 'bydesign' and obj2._meta.app_label == 'bydesign':
            return True
        if obj1._meta.app_label == 'bydesign' or obj2._meta.app_label == 'bydesign':
            return False
        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):
        """
        No migrations on the bd database.
        """
        if db == 'bd':
            return False
        return None



from django.contrib import admin

from .models import *


# admin.site.register(BiAutoship)
# admin.site.register(BiAutoshipdetails)
# admin.site.register(BiAutoshipperiodtypes)
# admin.site.register(BiBonusagentgroups)
# admin.site.register(BiBonusagents)
# admin.site.register(BiBonusdetails)
# admin.site.register(BiBonusRun)
# admin.site.register(BiBonustypes)
# admin.site.register(BiCompMatrixData)
# admin.site.register(BiCurrencies)
# admin.site.register(BiCustomers)
# admin.site.register(BiCustomertypes)

class BiInventoryAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'item_field',
        'description',
        'explanation',
        'taxcode',
        'isactive',
        'currencyid',
        'category',
        'cost',
        'featureditemreps',
        'featureditemcustomers',
        'outofstocklevel',
        'outofstockmessage',
        'lowstocklevel',
        'lowstockmessage',
        'sortorder',
        'virtualitem',
        'freeshipping',
        'shippingsurcharge',
        'shippingsurchargebase',
        'weight',
        'groupitemoverrideweight',
        'handlingfee',
        'datecreated',
    ]
admin.site.register(BiInventory, BiInventoryAdmin)

# admin.site.register(BiInventorycategory)
# admin.site.register(BiInventorycountry)
# admin.site.register(BiInventorygroups)
# admin.site.register(BiInventoryprices)
# admin.site.register(BiInventorywarehouse)
# admin.site.register(BiOrderdetails)
# admin.site.register(BiOrderdetailstatuses)
# admin.site.register(BiOrders)
# admin.site.register(BiOrderstatuses)
# admin.site.register(BiPayments)
# admin.site.register(BiPaymentstatustypes)
# admin.site.register(BiPaymenttypes)
# admin.site.register(BiPayoutdetails)
# admin.site.register(BiPayoutmethods)
# admin.site.register(BiPayoutprocesses)
# admin.site.register(BiQualificationAgent)
# admin.site.register(BiQualificationAgentValue)
# admin.site.register(BiRankpricetypes)
# admin.site.register(BiRank)
# admin.site.register(BiRepBonusData)
# admin.site.register(BiRep)
# admin.site.register(BiReptypes)
# admin.site.register(BiShipmethods)
# admin.site.register(BiTaxcodes)
# admin.site.register(BiWarehouses)
# admin.site.register(MssubscriptionAgents)



# This is an auto-generated Django model module.
# You'll have to do the following manually to clean this up:
#   * Rearrange models' order
#   * Make sure each model has one field with primary_key=True
#   * Remove `managed = False` lines if you wish to allow Django to create, modify, and delete the table
# Feel free to rename the models, but don't rename db_table values or field names.
#
# Also note: You'll have to insert the output of 'django-admin sqlcustom [app_label]'
# into your database.

from __future__ import unicode_literals

import sys

from django.db import models


# the database is only created during tests
IS_MANAGED = 'testing' not in sys.argv


class BiAutoship(models.Model):
    rep_field = models.CharField(db_column='Rep #', max_length=20, blank=True, null=True)
    repid = models.IntegerField(db_column='RepID')
    customerid = models.IntegerField(db_column='CustomerID')
    bcid = models.IntegerField(db_column='BCID')
    autoshipscheduleid = models.IntegerField(db_column='AutoshipScheduleID')
    autoshipperiodtypeid = models.IntegerField(db_column='AutoshipPeriodTypeID')
    period_unit = models.IntegerField(db_column='Period Unit')
    startdate = models.DateTimeField(db_column='StartDate')
    stopdate = models.DateTimeField(db_column='StopDate')
    datenextrun = models.DateTimeField(db_column='DateNextRun')
    autoshipruleid = models.IntegerField(db_column='AutoshipRuleID', blank=True, null=True)
    shipmethodid = models.IntegerField(db_column='ShipMethodID', blank=True, null=True)
    shipname1 = models.CharField(db_column='ShipName1', max_length=50, blank=True, null=True)
    shipname2 = models.CharField(db_column='ShipName2', max_length=50, blank=True, null=True)
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)
    shipphone = models.CharField(db_column='ShipPhone', max_length=50, blank=True, null=True)
    creditcardprofileid = models.IntegerField(db_column='CreditCardProfileID', blank=True, null=True)
    achprofileid = models.IntegerField(db_column='ACHProfileID', blank=True, null=True)
    checkdraftprofileid = models.IntegerField(db_column='CheckDraftProfileID', blank=True, null=True)
    orderid = models.IntegerField(db_column='OrderID', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_autoship'


class BiAutoshipdetails(models.Model):
    autoshipscheduleid = models.IntegerField(db_column='AutoshipScheduleID')
    autoshipdetailid = models.IntegerField(db_column='AutoShipDetailID')
    inventoryid = models.IntegerField(db_column='InventoryID')
    groupitem = models.SmallIntegerField(db_column='GroupItem', blank=True, null=True)
    quantity = models.IntegerField(db_column='Quantity')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_autoshipdetails'


class BiAutoshipperiodtypes(models.Model):
    id = models.IntegerField(db_column='ID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=25, blank=True, null=True)
    explanation = models.CharField(db_column='Explanation', max_length=150, blank=True, null=True)
    repextdescription = models.CharField(db_column='RepExtDescription', max_length=100, blank=True, null=True)
    custextdescription = models.CharField(db_column='CustExtDescription', max_length=100, blank=True, null=True)
    datepart = models.TextField(db_column='DatePart')
    increment = models.SmallIntegerField(db_column='Increment')
    useperiodday = models.SmallIntegerField(db_column='UsePeriodDay')
    isactive = models.SmallIntegerField(db_column='IsActive')
    isallowextranetedit = models.SmallIntegerField(db_column='IsAllowExtranetEdit')
    isrepextallowselection = models.SmallIntegerField(db_column='IsRepExtAllowSelection')
    iscustextallowselection = models.SmallIntegerField(db_column='IsCustExtAllowSelection')
    isallowexteditpayments = models.SmallIntegerField(db_column='IsAllowExtEditPayments', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_autoshipperiodtypes'


class BiBonusagentgroups(models.Model):
    id = models.IntegerField(db_column='BonusGroupID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_bonusagentgroups'


class BiBonusagents(models.Model):
    id = models.IntegerField(db_column='BonusAgentID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)
    configurationid = models.IntegerField(db_column='ConfigurationID')
    bonusagentgroupid = models.IntegerField(db_column='BonusAgentGroupID', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_bonusagents'


class BiBonusdetails(models.Model):
    id = models.IntegerField(primary_key=True, db_column='BonusDetailID')
    amount = models.DecimalField(db_column='Amount', max_digits=19, decimal_places=4)
    rep = models.ForeignKey(
        "BiRep", db_column='RepID', on_delete=models.DO_NOTHING)
    payon_rep = models.ForeignKey(
        "BiRep", db_column='PayOnRepID', max_length=20, blank=True, null=True,
        related_name="payon_bonus_details", on_delete=models.DO_NOTHING)
    bonusrun = models.ForeignKey("BiBonusRun", db_column='BonusRunID', on_delete=models.DO_NOTHING)
    bonustype = models.ForeignKey("BiBonustypes", db_column='BonusTypeID', on_delete=models.DO_NOTHING)
    orderid = models.IntegerField(db_column='OrderID')
    bonustypereportingvalue1 = models.DecimalField(db_column='BonusTypeReportingValue1', max_digits=18, decimal_places=6)
    bonustypereportingvalue2 = models.DecimalField(db_column='BonusTypeReportingValue2', max_digits=18, decimal_places=6)
    bonustypereportingvalue3 = models.DecimalField(db_column='BonusTypeReportingValue3', max_digits=18, decimal_places=6)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_bonusdetails'


class BiBonusRun(models.Model):
    id = models.IntegerField(primary_key=True, db_column='BonusRunID')
    bonus_description = models.CharField(db_column='Bonus Description', max_length=50, blank=True, null=True)
    period_start = models.DateTimeField(db_column='PeriodStartDate')
    period_end = models.DateTimeField(db_column='PeriodEndDate')
    qualify_start = models.DateTimeField(db_column='QualifyStartDate', blank=True, null=True)
    qualify_end = models.DateTimeField(db_column='QualifyEndDate', blank=True, null=True)
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_bonusruns'


class BiBonustypes(models.Model):
    id = models.IntegerField(primary_key=True, db_column='BonusAgentID')
    description = models.CharField(db_column='Description', max_length=50)
    periodcalendar = models.CharField(db_column='PeriodCalendar', max_length=200, blank=True, null=True)
    isactive = models.IntegerField(db_column='IsActive')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_bonustypes'


class BiCompMatrixData(models.Model):
    id = models.IntegerField(db_column='ID', primary_key=True)  # Field name made lowercase.
    compentityid = models.IntegerField(db_column='CompEntityID')  # Field name made lowercase.
    compentitytypeid = models.IntegerField(db_column='CompEntityTypeID')  # Field name made lowercase.
    dependentcomprankid = models.IntegerField(db_column='DependentCompRankID', blank=True, null=True)  # Field name made lowercase.
    agent = models.ForeignKey(BiBonusagents, db_column='DependentCompQualAgentID', blank=True, null=True, on_delete=models.DO_NOTHING)  # Field name made lowercase.
    amount = models.FloatField(db_column='Amount', blank=True, null=True)  # Field name made lowercase.
    generation = models.IntegerField(db_column='Generation', blank=True, null=True)  # Field name made lowercase.
    minamount = models.DecimalField(db_column='MinAmount', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    maxamount = models.DecimalField(db_column='MaxAmount', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    value1 = models.DecimalField(db_column='Value1', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    value2 = models.DecimalField(db_column='Value2', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100)  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_compmatrixdata'


class BiCurrencies(models.Model):
    currencyid = models.IntegerField(db_column='CurrencyID')
    description = models.CharField(db_column='Description', max_length=50)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10)
    active = models.SmallIntegerField(db_column='Active')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_currencies'


class BiCustomers(models.Model):
    customerid = models.IntegerField(db_column='CustomerID', primary_key=True)
    customer_field = models.CharField(db_column='Customer #', max_length=20, blank=True, null=True)
    repid = models.IntegerField(db_column='RepID')
    firstname = models.CharField(db_column='FirstName', max_length=50, blank=True, null=True)
    lastname = models.CharField(db_column='LastName', max_length=50, blank=True, null=True)
    middleinitial = models.CharField(db_column='MiddleInitial', max_length=1, blank=True, null=True)
    joindate = models.DateTimeField(db_column='JoinDate')
    email = models.CharField(db_column='Email', max_length=50, blank=True, null=True)
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)
    dateofbirth = models.DateTimeField(db_column='DateOfBirth', blank=True, null=True)
    customertypeid = models.IntegerField(db_column='CustomerTypeID')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_customers'

    def __unicode__(self):
        return u'{} {}'.format(self.firstname, self.lastname)


class BiCustomertypes(models.Model):
    customertypeid = models.IntegerField(db_column='CustomerTypeID')
    description = models.CharField(db_column='Description', max_length=50)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_customertypes'


class BiInventory(models.Model):
    id = models.IntegerField(db_column='InventoryID', primary_key=True)
    item_field = models.CharField(db_column='Item #', max_length=20)
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)
    explanation = models.CharField(db_column='Explanation', max_length=1000, blank=True, null=True)
    taxcode = models.CharField(db_column='TaxCode', max_length=25)
    isactive = models.SmallIntegerField(db_column='IsActive')
    currencyid = models.IntegerField(db_column='CurrencyID')
    category = models.CharField(db_column='Category', max_length=100)
    cost = models.DecimalField(db_column='Cost', max_digits=19, decimal_places=4, blank=True, null=True)
    featureditemreps = models.SmallIntegerField(db_column='FeaturedItemReps')
    featureditemcustomers = models.SmallIntegerField(db_column='FeaturedItemCustomers')
    outofstocklevel = models.IntegerField(db_column='OutOfStockLevel')
    outofstockmessage = models.CharField(db_column='OutOfStockMessage', max_length=1000, blank=True, null=True)
    lowstocklevel = models.IntegerField(db_column='LowStockLevel')
    lowstockmessage = models.CharField(db_column='LowStockMessage', max_length=1000, blank=True, null=True)
    sortorder = models.IntegerField(db_column='SortOrder')
    virtualitem = models.IntegerField(db_column='VirtualItem')
    freeshipping = models.SmallIntegerField(db_column='FreeShipping')
    shippingsurcharge = models.DecimalField(db_column='ShippingSurcharge', max_digits=19, decimal_places=4)
    shippingsurchargebase = models.DecimalField(db_column='ShippingSurchargeBase', max_digits=19, decimal_places=4)
    weight = models.DecimalField(db_column='Weight', max_digits=10, decimal_places=4, blank=True, null=True)
    groupitemoverrideweight = models.DecimalField(db_column='GroupItemOverrideWeight', max_digits=18, decimal_places=2, blank=True, null=True)
    handlingfee = models.DecimalField(db_column='HandlingFee', max_digits=19, decimal_places=4, blank=True, null=True)
    datecreated = models.DateTimeField(db_column='DateCreated')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventory'


class BiInventorycategory(models.Model):
    categoryid = models.IntegerField(db_column='CategoryID')
    category = models.CharField(db_column='Category', max_length=100)
    subcategory = models.CharField(db_column='SubCategory', max_length=100, blank=True, null=True)
    sortorder = models.IntegerField(db_column='SortOrder')
    datecreated = models.DateTimeField(db_column='DateCreated')
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventorycategory'


class BiInventorycountry(models.Model):
    inventoryid = models.IntegerField(db_column='InventoryID')
    country = models.CharField(db_column='Country', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventorycountry'


class BiInventorygroups(models.Model):
    groupid = models.IntegerField(db_column='GroupID')
    parentinventoryid = models.IntegerField(db_column='ParentInventoryID')
    childinventoryid = models.IntegerField(db_column='ChildInventoryID')
    quantity = models.IntegerField(db_column='Quantity', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventorygroups'


class BiInventoryPrice(models.Model):
    id = models.IntegerField(db_column='PriceID', primary_key=True)
    inventory = models.ForeignKey(BiInventory, db_column='InventoryID', on_delete=models.DO_NOTHING)
    ranktype = models.ForeignKey("BiRank", db_column='RanktypeID', on_delete=models.DO_NOTHING)
    pricetext = models.CharField(db_column='PriceText', max_length=25)
    currencyid = models.IntegerField(db_column='CurrencyID')
    price = models.DecimalField(db_column='Price', max_digits=19, decimal_places=4)
    volume1 = models.DecimalField(db_column='Volume1', max_digits=19, decimal_places=4)
    volume2 = models.DecimalField(db_column='Volume2', max_digits=19, decimal_places=4)
    volume3 = models.DecimalField(db_column='Volume3', max_digits=19, decimal_places=4)
    volume4 = models.DecimalField(db_column='Volume4', max_digits=19, decimal_places=4)
    otherprice1 = models.DecimalField(db_column='OtherPrice1', max_digits=19, decimal_places=4)
    otherprice2 = models.DecimalField(db_column='OtherPrice2', max_digits=19, decimal_places=4)
    otherprice3 = models.DecimalField(db_column='OtherPrice3', max_digits=19, decimal_places=4)
    otherprice4 = models.DecimalField(db_column='OtherPrice4', max_digits=19, decimal_places=4)
    compare = models.DecimalField(db_column='Compare', max_digits=19, decimal_places=4)
    taxableamount = models.DecimalField(db_column='TaxableAmount', max_digits=19, decimal_places=4)
    startdate = models.DateTimeField(db_column='StartDate')
    enddate = models.DateTimeField(db_column='EndDate')
    datecreated = models.DateTimeField(db_column='DateCreated')
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)
    returnprice = models.DecimalField(db_column='ReturnPrice', max_digits=19, decimal_places=4, blank=True, null=True)
    mup_qtystart = models.IntegerField(db_column='MUP_QtyStart')
    mup_qtystop = models.IntegerField(db_column='MUP_QtyStop')
    mup_qtyvalue = models.IntegerField(db_column='MUP_QtyValue')
    shippingvalue = models.DecimalField(db_column='ShippingValue', max_digits=19, decimal_places=4, blank=True, null=True)
    vattax = models.DecimalField(db_column='VATTax', max_digits=19, decimal_places=4)
    handlingfee = models.DecimalField(db_column='HandlingFee', max_digits=19, decimal_places=4, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventoryprices'


class BiInventorywarehouse(models.Model):
    inventory = models.OneToOneField("BiInventory", db_column='InventoryID', primary_key=True, on_delete=models.DO_NOTHING)
    warehouse = models.OneToOneField("BiWarehouses", db_column='WarehouseID', on_delete=models.DO_NOTHING)
    onhand = models.IntegerField(db_column='OnHand')
    reorderpoint = models.IntegerField(db_column='ReOrderPoint', blank=True, null=True)
    onhandshipped = models.IntegerField(db_column='OnHandShipped')
    cost = models.DecimalField(db_column='Cost', max_digits=19, decimal_places=4)
    idealonhand = models.IntegerField(db_column='IdealOnHand')
    avgweightedcost = models.DecimalField(db_column='AvgWeightedCost', max_digits=19, decimal_places=4)
    packslipsortorder = models.IntegerField(db_column='PackSlipSortOrder')
    outofstocklevel = models.IntegerField(db_column='OutOfStockLevel')
    outofstockmessage = models.CharField(db_column='OutOfStockMessage', max_length=300, blank=True, null=True)
    lowstocklevel = models.IntegerField(db_column='LowStockLevel')
    lowstockmessage = models.CharField(db_column='LowStockMessage', max_length=300, blank=True, null=True)
    packslipproductid = models.CharField(db_column='PackslipProductID', max_length=40, blank=True, null=True)
    packslipdescription = models.CharField(db_column='PackslipDescription', max_length=200, blank=True, null=True)
    softcount = models.IntegerField(db_column='SoftCount')
    datecreated = models.DateTimeField(db_column='DateCreated')
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_inventorywarehouse'


class BiOrderdetails(models.Model):
    order = models.ForeignKey("BiOrders", related_name="items", db_column='OrderID', on_delete=models.DO_NOTHING)
    id = models.IntegerField(db_column='OrderDetailID', primary_key=True)
    orderdetailstatusid = models.IntegerField(db_column='OrderDetailStatusID')
    inventory = models.ForeignKey("BiInventory", db_column='InventoryID', on_delete=models.DO_NOTHING)
    groupitem = models.IntegerField(db_column='GroupItem')
    groupownerdetailid = models.IntegerField(db_column='GroupOwnerDetailID')
    packslipped = models.IntegerField(db_column='PackSlipped')
    quantity = models.IntegerField(db_column='Quantity')
    volume1 = models.DecimalField(db_column='Volume1', max_digits=19, decimal_places=4)
    volume2 = models.DecimalField(db_column='Volume2', max_digits=19, decimal_places=4)
    volume3 = models.DecimalField(db_column='Volume3', max_digits=19, decimal_places=4)
    volume4 = models.DecimalField(db_column='Volume4', max_digits=19, decimal_places=4)
    otherprice1 = models.DecimalField(db_column='OtherPrice1', max_digits=19, decimal_places=4)
    otherprice2 = models.DecimalField(db_column='OtherPrice2', max_digits=19, decimal_places=4)
    otherprice3 = models.DecimalField(db_column='OtherPrice3', max_digits=19, decimal_places=4)
    otherprice4 = models.DecimalField(db_column='OtherPrice4', max_digits=19, decimal_places=4)
    price = models.DecimalField(db_column='Price', max_digits=19, decimal_places=4)
    tax = models.DecimalField(db_column='Tax', max_digits=19, decimal_places=4, blank=True, null=True)
    taxableamount = models.DecimalField(db_column='TaxableAmount', max_digits=19, decimal_places=4)
    compare = models.DecimalField(db_column='Compare', max_digits=19, decimal_places=4)
    trackingid = models.CharField(db_column='TrackingID', max_length=50, blank=True, null=True)
    warehouseid = models.IntegerField(db_column='WarehouseID', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_orderdetails'


class BiOrderdetailstatuses(models.Model):
    orderdetailstatusid = models.IntegerField(db_column='OrderDetailStatusID')
    description = models.CharField(db_column='Description', max_length=50)
    official = models.SmallIntegerField(db_column='Official')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_orderdetailstatuses'


class BiOrders(models.Model):
    id = models.IntegerField(db_column='OrderID', primary_key=True)
    rep = models.ForeignKey("BiRep", db_column='RepID', on_delete=models.DO_NOTHING)
    bcid = models.IntegerField(db_column='BCID')
    customer = models.ForeignKey("BiCustomers", db_column='CustomerID', blank=True, null=True, on_delete=models.DO_NOTHING)
    partyid = models.IntegerField(db_column='PartyID', blank=True, null=True)
    orderdate = models.DateTimeField(db_column='OrderDate')
    bonusdate = models.DateTimeField(db_column='BonusDate')
    dateshipped = models.DateTimeField(db_column='DateShipped', blank=True, null=True)
    status = models.ForeignKey("BiOrderstatuses", db_column='OrderStatusID', on_delete=models.DO_NOTHING)
    rankpricetypeid = models.IntegerField(db_column='RankPriceTypeID')
    shipping = models.DecimalField(db_column='Shipping', max_digits=19, decimal_places=4)
    handling = models.DecimalField(db_column='Handling', max_digits=19, decimal_places=4)
    shippingtax = models.DecimalField(db_column='ShippingTax', max_digits=19, decimal_places=4)
    handlingtax = models.DecimalField(db_column='HandlingTax', max_digits=19, decimal_places=4)
    totalprice = models.DecimalField(db_column='TotalPrice', max_digits=19, decimal_places=4)
    currencytypeid = models.IntegerField(db_column='CurrencyTypeID', blank=True, null=True)
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)
    dateposted = models.DateTimeField(db_column='DatePosted', blank=True, null=True)
    market = models.TextField(db_column='Market', blank=True, null=True)
    shipmethod = models.ForeignKey("BiShipmethods", db_column='ShipMethodID', blank=True, null=True, on_delete=models.DO_NOTHING)
    order_type = models.TextField(db_column='Order Type')
    orderlinkid = models.IntegerField(db_column='OrderLinkID', blank=True, null=True)
    autoshipscheduleid = models.IntegerField(db_column='AutoShipScheduleID', blank=True, null=True)
    autoshipbatchid = models.IntegerField(db_column='AutoshipBatchID', blank=True, null=True)
    invoicenotes = models.CharField(db_column='InvoiceNotes', max_length=500, blank=True, null=True)
    geocode = models.CharField(db_column='GeoCode', max_length=10, blank=True, null=True)
    created = models.DateTimeField(db_column='DateCreated')
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_orders'


class BiOrderstatuses(models.Model):
    id = models.IntegerField(db_column='OrderStatusID',primary_key=True)
    description = models.CharField(db_column='Description', max_length=25)
    official = models.SmallIntegerField(db_column='Official')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_orderstatuses'


class BiPayments(models.Model):
    id = models.IntegerField(primary_key=True, db_column='PaymentID')
    paymenttype = models.ForeignKey("BiPaymenttypes", db_column='PaymentTypeID', on_delete=models.DO_NOTHING)
    paymentdate = models.DateTimeField(db_column='PaymentDate')
    orderid = models.IntegerField(db_column='OrderID', blank=True, null=True)
    amount = models.DecimalField(db_column='Amount', max_digits=19, decimal_places=4)
    paymentstatustypeid = models.SmallIntegerField(db_column='PaymentStatusTypeID')
    datecreated = models.DateTimeField(db_column='DateCreated')
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_payments'


class BiPaymentstatustypes(models.Model):
    paymentstatustypeid = models.SmallIntegerField(db_column='PaymentStatusTypeID')
    description = models.CharField(db_column='Description', max_length=50)
    official = models.SmallIntegerField(db_column='Official')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_paymentstatustypes'


class BiPaymenttypes(models.Model):
    paymenttypeid = models.IntegerField(primary_key=True, db_column='PaymentTypeID')
    description = models.CharField(db_column='Description', max_length=25)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)
    startdate = models.DateTimeField(db_column='StartDate', blank=True, null=True)
    enddate = models.DateTimeField(db_column='EndDate', blank=True, null=True)
    autoship = models.SmallIntegerField(db_column='Autoship', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_paymenttypes'


class BiPayoutdetails(models.Model):
    payoutdetailid = models.IntegerField(db_column='PayoutDetailID')
    repid = models.IntegerField(db_column='RepID')
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')
    prevbalanceforward = models.DecimalField(db_column='PrevBalanceForward', max_digits=19, decimal_places=4)
    adjustments = models.DecimalField(db_column='Adjustments', max_digits=19, decimal_places=4)
    bonusamount = models.DecimalField(db_column='BonusAmount', max_digits=19, decimal_places=4)
    preconversionamount = models.DecimalField(db_column='PreConversionAmount', max_digits=19, decimal_places=4)
    postconversionamount = models.DecimalField(db_column='PostConversionAmount', max_digits=19, decimal_places=4)
    balanceforward = models.DecimalField(db_column='BalanceForward', max_digits=19, decimal_places=4)
    payoutfee = models.DecimalField(db_column='PayoutFee', max_digits=19, decimal_places=4)
    reference_field = models.IntegerField(db_column='Reference #')
    datecreated = models.DateTimeField(db_column='DateCreated')
    preconversioncurrencyid = models.IntegerField(db_column='PreConversionCurrencyID')
    postconversioncurrencyid = models.IntegerField(db_column='PostConversionCurrencyID')
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_payoutdetails'


class BiPayoutmethods(models.Model):
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID')
    description = models.CharField(db_column='Description', max_length=50)
    nextreferencenumber = models.IntegerField(db_column='NextReferenceNumber')
    active = models.SmallIntegerField(db_column='Active')
    minpayoutamount = models.DecimalField(db_column='MinPayoutAmount', max_digits=19, decimal_places=4)
    processingfee = models.DecimalField(db_column='ProcessingFee', max_digits=19, decimal_places=4)
    payoutmethodtype = models.CharField(db_column='PayoutMethodType', max_length=50)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_payoutmethods'


class BiPayoutprocesses(models.Model):
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')
    description = models.CharField(db_column='Description', max_length=250, blank=True, null=True)
    datecreated = models.DateTimeField(db_column='DateCreated')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_payoutprocesses'


class BiQualificationAgent(models.Model):
    id = models.IntegerField(db_column='QualificationAgentID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=200, blank=True, null=True)
    configuration = models.CharField(db_column='Configuration', max_length=100, blank=True, null=True)
    qualificationagent_groupid = models.IntegerField(db_column='QualificationAgent_GroupID', blank=True, null=True)
    bonus_parameter = models.TextField(db_column='Bonus Parameter')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_qualificationagents'


class BiQualificationAgentValue(models.Model):
    agent = models.OneToOneField(BiQualificationAgent, db_column='QualificationAgentID', primary_key=True, on_delete=models.DO_NOTHING)
    rep_bonus_data = models.OneToOneField("BiRepBonusData", db_column='BonusRepID', on_delete=models.DO_NOTHING)
    value = models.FloatField(db_column='Value', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_qualificationagentvalues'


class BiRankPriceType(models.Model):
    id = models.IntegerField(db_column='RankPriceTypeID', primary_key=True)
    rank = models.ForeignKey("BiRank", db_column='RankID', on_delete=models.DO_NOTHING)
    description = models.CharField(db_column='Description', max_length=25)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_rankpricetypes'


class BiRank(models.Model):
    id = models.IntegerField(db_column='RankID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=50)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)
    active = models.SmallIntegerField(db_column='Active')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_ranks'

    def __unicode__(self):
        return self.description


class BiRepBonusData(models.Model):
    id = models.BigIntegerField(db_column='BonusRepID', primary_key=True)
    bonusrun = models.ForeignKey("BiBonusRun", db_column='BonusRunID', on_delete=models.DO_NOTHING)
    rep = models.ForeignKey("BiRep", db_column='RepID', on_delete=models.DO_NOTHING)
    title_rank = models.ForeignKey("BiRank", related_name="+", db_column='TitleRankID', on_delete=models.DO_NOTHING)
    bonus_rank = models.ForeignKey("BiRank", db_column='BonusRankID', blank=True, null=True, on_delete=models.DO_NOTHING)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_repbonusdata'


class BiRep(models.Model):
    id = models.IntegerField(db_column='RepID', primary_key=True)
    rep_field = models.CharField(db_column='Rep #', max_length=20)
    enroller = models.ForeignKey("self", db_column='EnrollerRepID', blank=True, null=True, on_delete=models.DO_NOTHING)
    uplinebcid = models.IntegerField(db_column='UplineBCID', blank=True, null=True)
    bcposition = models.TextField(db_column='BCPosition', blank=True, null=True)
    bcid = models.IntegerField(db_column='BCID')
    bc_field = models.IntegerField(db_column='BC #', blank=True, null=True)
    firstname = models.CharField(db_column='FirstName', max_length=50, blank=True, null=True)
    lastname = models.CharField(db_column='LastName', max_length=50, blank=True, null=True)
    middleinitial = models.CharField(db_column='MiddleInitial', max_length=1, blank=True, null=True)
    join_date = models.DateTimeField(db_column='JoinDate')
    email = models.CharField(db_column='Email', max_length=50, blank=True, null=True)
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)
    dateofbirth = models.DateTimeField(db_column='DateOfBirth', blank=True, null=True)
    renewal_date = models.DateTimeField(db_column='RenewalDate')
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID', blank=True, null=True)
    type = models.ForeignKey("BiReptypes", db_column='RepTypeID', on_delete=models.DO_NOTHING)
    rank = models.ForeignKey("BiRank", db_column='RankID', on_delete=models.DO_NOTHING)
    taxid1 = models.CharField(db_column='TaxID1', max_length=50, blank=True, null=True)
    taxid2 = models.CharField(db_column='TaxID2', max_length=50, blank=True, null=True)
    taxexempt = models.SmallIntegerField(db_column='TaxExempt', blank=True, null=True)
    phone1 = models.CharField(db_column='Phone1', max_length=50, blank=True, null=True)
    phone2 = models.CharField(db_column='Phone2', max_length=50, blank=True, null=True)
    phone3 = models.CharField(db_column='Phone3', max_length=50, blank=True, null=True)
    phone4 = models.CharField(db_column='Phone4', max_length=50, blank=True, null=True)
    phone5 = models.CharField(db_column='Phone5', max_length=50, blank=True, null=True)
    phone6 = models.CharField(db_column='Phone6', max_length=50, blank=True, null=True)
    preferredculture = models.IntegerField(db_column='PreferredCulture')
    created = models.DateTimeField(db_column='DateCreated')
    last_modified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)
    date_cancelled = models.DateTimeField(db_column='Date Cancelled', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_reps'

    def __unicode__(self):
        return u'#{} ({} {})'.format(self.id, self.firstname, self.lastname)


class BiReptypes(models.Model):
    id = models.IntegerField(primary_key=True, db_column='RepTypeID')
    description = models.CharField(db_column='Description', max_length=50)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_reptypes'

    def __unicode__(self):
        return self.description


class BiShipmethods(models.Model):
    id = models.IntegerField(db_column='ShipMethodID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=50)
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)
    shipper = models.CharField(db_column='Shipper', max_length=50)
    website = models.CharField(db_column='Website', max_length=100, blank=True, null=True)
    trackingurl = models.CharField(db_column='TrackingURL', max_length=250, blank=True, null=True)
    active = models.SmallIntegerField(db_column='Active')
    multipleunit = models.CharField(db_column='MultipleUnit', max_length=50, blank=True, null=True)
    web = models.SmallIntegerField(db_column='Web', blank=True, null=True)
    priority = models.IntegerField(db_column='Priority')
    immediate = models.SmallIntegerField(db_column='Immediate', blank=True, null=True)
    surchargepercentage = models.DecimalField(db_column='SurchargePercentage', max_digits=18, decimal_places=8)
    handlingfeeaware = models.SmallIntegerField(db_column='HandlingFeeAware')
    surchargebase = models.DecimalField(db_column='SurchargeBase', max_digits=19, decimal_places=4)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_shipmethods'


class BiTaxcodes(models.Model):
    id = models.CharField(db_column='TaxCodeID', max_length=25, primary_key=True)
    description = models.CharField(db_column='Description', max_length=250, blank=True, null=True)
    visibleonextranet = models.SmallIntegerField(db_column='VisibleOnExtranet', blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_taxcodes'


class BiWarehouses(models.Model):
    warehouseid = models.IntegerField(db_column='WarehouseID', primary_key=True)
    description = models.CharField(db_column='Description', max_length=50)
    packslipline1 = models.CharField(db_column='PackSlipLine1', max_length=100, blank=True, null=True)
    packslipline2 = models.CharField(db_column='PackSlipLine2', max_length=100, blank=True, null=True)
    packslipline3 = models.CharField(db_column='PackSlipLine3', max_length=100, blank=True, null=True)
    packslipline4 = models.CharField(db_column='PackSlipLine4', max_length=100, blank=True, null=True)
    packslipline5 = models.CharField(db_column='PackSlipLine5', max_length=100, blank=True, null=True)
    packslipline6 = models.CharField(db_column='PackSlipLine6', max_length=100, blank=True, null=True)
    active = models.SmallIntegerField(db_column='Active')

    class Meta:
        managed = IS_MANAGED
        db_table = 'bi_warehouses'


class MssubscriptionAgents(models.Model):
    id = models.IntegerField(primary_key=True)
    publisher = models.CharField(max_length=128)
    publisher_db = models.CharField(max_length=128)
    publication = models.CharField(max_length=128)
    subscription_type = models.IntegerField()
    queue_id = models.CharField(max_length=128, blank=True, null=True)
    update_mode = models.SmallIntegerField()
    failover_mode = models.BooleanField(default=False)
    spid = models.IntegerField()
    login_time = models.DateTimeField()
    allow_subscription_copy = models.BooleanField(default=False)
    attach_state = models.IntegerField()
    attach_version = models.BinaryField()
    last_sync_status = models.IntegerField(blank=True, null=True)
    last_sync_summary = models.CharField(max_length=128, blank=True, null=True)
    last_sync_time = models.DateTimeField(blank=True, null=True)
    queue_server = models.CharField(max_length=128, blank=True, null=True)

    class Meta:
        managed = IS_MANAGED
        db_table = 'mssubscription_agents'



# This is an auto-generated Django model module.
# You'll have to do the following manually to clean this up:
#   * Rearrange models' order
#   * Make sure each model has one field with primary_key=True
#   * Remove `managed = False` lines if you wish to allow Django to create, modify, and delete the table
# Feel free to rename the models, but don't rename db_table values or field names.
#
# Also note: You'll have to insert the output of 'django-admin sqlcustom [app_label]'
# into your database.
from __future__ import unicode_literals

from django.db import models


class BiAutoship(models.Model):
    rep_field = models.CharField(db_column='Rep #', max_length=20, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    customerid = models.IntegerField(db_column='CustomerID')  # Field name made lowercase.
    bcid = models.IntegerField(db_column='BCID')  # Field name made lowercase.
    autoshipscheduleid = models.IntegerField(db_column='AutoshipScheduleID')  # Field name made lowercase.
    autoshipperiodtypeid = models.IntegerField(db_column='AutoshipPeriodTypeID')  # Field name made lowercase.
    period_unit = models.IntegerField(db_column='Period Unit')  # Field name made lowercase. Field renamed to remove unsuitable characters.
    startdate = models.DateTimeField(db_column='StartDate')  # Field name made lowercase.
    stopdate = models.DateTimeField(db_column='StopDate')  # Field name made lowercase.
    datenextrun = models.DateTimeField(db_column='DateNextRun')  # Field name made lowercase.
    autoshipruleid = models.IntegerField(db_column='AutoshipRuleID', blank=True, null=True)  # Field name made lowercase.
    shipmethodid = models.IntegerField(db_column='ShipMethodID', blank=True, null=True)  # Field name made lowercase.
    shipname1 = models.CharField(db_column='ShipName1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipname2 = models.CharField(db_column='ShipName2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipphone = models.CharField(db_column='ShipPhone', max_length=50, blank=True, null=True)  # Field name made lowercase.
    creditcardprofileid = models.IntegerField(db_column='CreditCardProfileID', blank=True, null=True)  # Field name made lowercase.
    achprofileid = models.IntegerField(db_column='ACHProfileID', blank=True, null=True)  # Field name made lowercase.
    checkdraftprofileid = models.IntegerField(db_column='CheckDraftProfileID', blank=True, null=True)  # Field name made lowercase.
    orderid = models.IntegerField(db_column='OrderID', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_autoship'


class BiAutoshipdetails(models.Model):
    autoshipscheduleid = models.IntegerField(db_column='AutoshipScheduleID')  # Field name made lowercase.
    autoshipdetailid = models.IntegerField(db_column='AutoShipDetailID')  # Field name made lowercase.
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    groupitem = models.SmallIntegerField(db_column='GroupItem', blank=True, null=True)  # Field name made lowercase.
    quantity = models.IntegerField(db_column='Quantity')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_autoshipdetails'


class BiAutoshipperiodtypes(models.Model):
    id = models.IntegerField(db_column='ID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=25, blank=True, null=True)  # Field name made lowercase.
    explanation = models.CharField(db_column='Explanation', max_length=150, blank=True, null=True)  # Field name made lowercase.
    repextdescription = models.CharField(db_column='RepExtDescription', max_length=100, blank=True, null=True)  # Field name made lowercase.
    custextdescription = models.CharField(db_column='CustExtDescription', max_length=100, blank=True, null=True)  # Field name made lowercase.
    datepart = models.TextField(db_column='DatePart')  # Field name made lowercase.
    increment = models.SmallIntegerField(db_column='Increment')  # Field name made lowercase.
    useperiodday = models.SmallIntegerField(db_column='UsePeriodDay')  # Field name made lowercase.
    isactive = models.SmallIntegerField(db_column='IsActive')  # Field name made lowercase.
    isallowextranetedit = models.SmallIntegerField(db_column='IsAllowExtranetEdit')  # Field name made lowercase.
    isrepextallowselection = models.SmallIntegerField(db_column='IsRepExtAllowSelection')  # Field name made lowercase.
    iscustextallowselection = models.SmallIntegerField(db_column='IsCustExtAllowSelection')  # Field name made lowercase.
    isallowexteditpayments = models.SmallIntegerField(db_column='IsAllowExtEditPayments', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_autoshipperiodtypes'


class BiBonusBonusdetails(models.Model):
    bonusdetailid = models.IntegerField(db_column='BonusDetailID')  # Field name made lowercase.
    amount = models.DecimalField(db_column='Amount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    payonrepid = models.CharField(db_column='PayOnRepID', max_length=20, blank=True, null=True)  # Field name made lowercase.
    bonusrunid = models.IntegerField(db_column='BonusRunID')  # Field name made lowercase.
    bonustypeid = models.IntegerField(db_column='BonusTypeID', blank=True, null=True)  # Field name made lowercase.
    orderid = models.IntegerField(db_column='OrderID')  # Field name made lowercase.
    bonustypereportingvalue1 = models.DecimalField(db_column='BonusTypeReportingValue1', max_digits=18, decimal_places=6)  # Field name made lowercase.
    bonustypereportingvalue2 = models.DecimalField(db_column='BonusTypeReportingValue2', max_digits=18, decimal_places=6)  # Field name made lowercase.
    bonustypereportingvalue3 = models.DecimalField(db_column='BonusTypeReportingValue3', max_digits=18, decimal_places=6)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonus_bonusdetails'


class BiBonusBonusrun(models.Model):
    bonus_run_field = models.IntegerField(db_column='Bonus Run #')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    bonus_description = models.CharField(db_column='Bonus Description', max_length=50, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    periodstartdate = models.DateTimeField(db_column='PeriodStartDate')  # Field name made lowercase.
    periodenddate = models.DateTimeField(db_column='PeriodEndDate')  # Field name made lowercase.
    qualifystartdate = models.DateTimeField(db_column='QualifyStartDate', blank=True, null=True)  # Field name made lowercase.
    qualifyenddate = models.DateTimeField(db_column='QualifyEndDate', blank=True, null=True)  # Field name made lowercase.
    payout_field = models.IntegerField(db_column='Payout #')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.

    class Meta:
        managed = False
        db_table = 'bi_bonus_bonusrun'


class BiBonusDynamicearnings(models.Model):
    rep_field = models.CharField(db_column='Rep #', max_length=20, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    pay_on_rep_field = models.CharField(db_column='Pay On Rep#', max_length=20, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    bonus_run_field = models.IntegerField(db_column='Bonus Run#')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    bonus_type = models.CharField(db_column='Bonus Type', max_length=100, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    periodstartdate = models.DateTimeField(db_column='PeriodStartDate')  # Field name made lowercase.
    periodenddate = models.DateTimeField(db_column='PeriodEndDate')  # Field name made lowercase.
    bonus_amount = models.DecimalField(db_column='Bonus Amount', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.

    class Meta:
        managed = False
        db_table = 'bi_bonus_dynamicearnings'


class BiBonusPayouts(models.Model):
    rep_field = models.CharField(db_column='Rep #', max_length=20)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    prev_balance_forward = models.DecimalField(db_column='Prev Balance Forward', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    adjustments = models.DecimalField(db_column='Adjustments', max_digits=19, decimal_places=4)  # Field name made lowercase.
    bonus_amount = models.DecimalField(db_column='Bonus Amount', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    amount_pre_field = models.DecimalField(db_column='Amount (Pre)', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    currency_pre_field = models.CharField(db_column='Currency (Pre)', max_length=10)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    amount_post_field = models.DecimalField(db_column='Amount (Post)', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    currency_post_field = models.CharField(db_column='Currency (Post)', max_length=10)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    balance_forward = models.DecimalField(db_column='Balance Forward', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    payout_field = models.IntegerField(db_column='Payout #')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    payout_description = models.CharField(db_column='Payout Description', max_length=250, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    payout_method = models.CharField(db_column='Payout Method', max_length=50)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    payout_fee = models.DecimalField(db_column='Payout Fee', max_digits=19, decimal_places=4)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    ref_field = models.IntegerField(db_column='Ref #')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    date_created = models.DateTimeField(db_column='Date Created')  # Field name made lowercase. Field renamed to remove unsuitable characters.

    class Meta:
        managed = False
        db_table = 'bi_bonus_payouts'


class BiBonusagentgroups(models.Model):
    bonusgroupid = models.IntegerField(db_column='BonusGroupID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonusagentgroups'


class BiBonusagents(models.Model):
    bonusagentid = models.IntegerField(db_column='BonusAgentID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)  # Field name made lowercase.
    configurationid = models.IntegerField(db_column='ConfigurationID')  # Field name made lowercase.
    bonusagentgroupid = models.IntegerField(db_column='BonusAgentGroupID', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonusagents'


class BiBonusdetails(models.Model):
    bonusdetailid = models.IntegerField(db_column='BonusDetailID')  # Field name made lowercase.
    amount = models.DecimalField(db_column='Amount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    payonrepid = models.CharField(db_column='PayOnRepID', max_length=20, blank=True, null=True)  # Field name made lowercase.
    bonusrunid = models.IntegerField(db_column='BonusRunID')  # Field name made lowercase.
    bonustypeid = models.IntegerField(db_column='BonusTypeID')  # Field name made lowercase.
    orderid = models.IntegerField(db_column='OrderID')  # Field name made lowercase.
    bonustypereportingvalue1 = models.DecimalField(db_column='BonusTypeReportingValue1', max_digits=18, decimal_places=6)  # Field name made lowercase.
    bonustypereportingvalue2 = models.DecimalField(db_column='BonusTypeReportingValue2', max_digits=18, decimal_places=6)  # Field name made lowercase.
    bonustypereportingvalue3 = models.DecimalField(db_column='BonusTypeReportingValue3', max_digits=18, decimal_places=6)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonusdetails'


class BiBonusruns(models.Model):
    bonusrunid = models.IntegerField(db_column='BonusRunID')  # Field name made lowercase.
    bonus_description = models.CharField(db_column='Bonus Description', max_length=50, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    periodstartdate = models.DateTimeField(db_column='PeriodStartDate')  # Field name made lowercase.
    periodenddate = models.DateTimeField(db_column='PeriodEndDate')  # Field name made lowercase.
    qualifystartdate = models.DateTimeField(db_column='QualifyStartDate', blank=True, null=True)  # Field name made lowercase.
    qualifyenddate = models.DateTimeField(db_column='QualifyEndDate', blank=True, null=True)  # Field name made lowercase.
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonusruns'


class BiBonustypes(models.Model):
    bonusagentid = models.IntegerField(db_column='BonusAgentID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    periodcalendar = models.CharField(db_column='PeriodCalendar', max_length=200, blank=True, null=True)  # Field name made lowercase.
    isactive = models.IntegerField(db_column='IsActive')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_bonustypes'


class BiCompconfigurations(models.Model):
    id = models.IntegerField(db_column='ID')  # Field name made lowercase.
    version = models.IntegerField(db_column='Version', blank=True, null=True)  # Field name made lowercase.
    signoffversion = models.CharField(db_column='SignoffVersion', max_length=10, blank=True, null=True)  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_compconfigurations'


class BiCompmatrixdata(models.Model):
    id = models.IntegerField(db_column='ID')  # Field name made lowercase.
    compentityid = models.IntegerField(db_column='CompEntityID')  # Field name made lowercase.
    compentitytypeid = models.IntegerField(db_column='CompEntityTypeID')  # Field name made lowercase.
    dependentcomprankid = models.IntegerField(db_column='DependentCompRankID', blank=True, null=True)  # Field name made lowercase.
    dependentcompqualagentid = models.IntegerField(db_column='DependentCompQualAgentID', blank=True, null=True)  # Field name made lowercase.
    amount = models.FloatField(db_column='Amount', blank=True, null=True)  # Field name made lowercase.
    generation = models.IntegerField(db_column='Generation', blank=True, null=True)  # Field name made lowercase.
    minamount = models.DecimalField(db_column='MinAmount', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    maxamount = models.DecimalField(db_column='MaxAmount', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    value1 = models.DecimalField(db_column='Value1', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    value2 = models.DecimalField(db_column='Value2', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100)  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_compmatrixdata'


class BiCompranks(models.Model):
    id = models.IntegerField(db_column='ID')  # Field name made lowercase.
    rankid = models.IntegerField(db_column='RankID', blank=True, null=True)  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=1000)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10)  # Field name made lowercase.
    compconfigurationid = models.IntegerField(db_column='CompConfigurationID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_compranks'


class BiCurrencies(models.Model):
    currencyid = models.IntegerField(db_column='CurrencyID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10)  # Field name made lowercase.
    active = models.SmallIntegerField(db_column='Active')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_currencies'


class BiCustomers(models.Model):
    customerid = models.IntegerField(db_column='CustomerID')  # Field name made lowercase.
    customer_field = models.CharField(db_column='Customer #', max_length=20, blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    firstname = models.CharField(db_column='FirstName', max_length=50, blank=True, null=True)  # Field name made lowercase.
    lastname = models.CharField(db_column='LastName', max_length=50, blank=True, null=True)  # Field name made lowercase.
    middleinitial = models.CharField(db_column='MiddleInitial', max_length=1, blank=True, null=True)  # Field name made lowercase.
    joindate = models.DateTimeField(db_column='JoinDate')  # Field name made lowercase.
    email = models.CharField(db_column='Email', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    dateofbirth = models.DateTimeField(db_column='DateOfBirth', blank=True, null=True)  # Field name made lowercase.
    customertypeid = models.IntegerField(db_column='CustomerTypeID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_customers'


class BiCustomertypes(models.Model):
    customertypeid = models.IntegerField(db_column='CustomerTypeID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_customertypes'


class BiInventory(models.Model):
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    item_field = models.CharField(db_column='Item #', max_length=20)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    description = models.CharField(db_column='Description', max_length=100, blank=True, null=True)  # Field name made lowercase.
    explanation = models.CharField(db_column='Explanation', max_length=1000, blank=True, null=True)  # Field name made lowercase.
    taxcode = models.CharField(db_column='TaxCode', max_length=25)  # Field name made lowercase.
    isactive = models.SmallIntegerField(db_column='IsActive')  # Field name made lowercase.
    currencyid = models.IntegerField(db_column='CurrencyID')  # Field name made lowercase.
    category = models.CharField(db_column='Category', max_length=100)  # Field name made lowercase.
    cost = models.DecimalField(db_column='Cost', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    featureditemreps = models.SmallIntegerField(db_column='FeaturedItemReps')  # Field name made lowercase.
    featureditemcustomers = models.SmallIntegerField(db_column='FeaturedItemCustomers')  # Field name made lowercase.
    outofstocklevel = models.IntegerField(db_column='OutOfStockLevel')  # Field name made lowercase.
    outofstockmessage = models.CharField(db_column='OutOfStockMessage', max_length=1000, blank=True, null=True)  # Field name made lowercase.
    lowstocklevel = models.IntegerField(db_column='LowStockLevel')  # Field name made lowercase.
    lowstockmessage = models.CharField(db_column='LowStockMessage', max_length=1000, blank=True, null=True)  # Field name made lowercase.
    sortorder = models.IntegerField(db_column='SortOrder')  # Field name made lowercase.
    virtualitem = models.IntegerField(db_column='VirtualItem')  # Field name made lowercase.
    freeshipping = models.SmallIntegerField(db_column='FreeShipping')  # Field name made lowercase.
    shippingsurcharge = models.DecimalField(db_column='ShippingSurcharge', max_digits=19, decimal_places=4)  # Field name made lowercase.
    shippingsurchargebase = models.DecimalField(db_column='ShippingSurchargeBase', max_digits=19, decimal_places=4)  # Field name made lowercase.
    weight = models.DecimalField(db_column='Weight', max_digits=10, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    groupitemoverrideweight = models.DecimalField(db_column='GroupItemOverrideWeight', max_digits=18, decimal_places=2, blank=True, null=True)  # Field name made lowercase.
    handlingfee = models.DecimalField(db_column='HandlingFee', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventory'


class BiInventorycategory(models.Model):
    categoryid = models.IntegerField(db_column='CategoryID')  # Field name made lowercase.
    category = models.CharField(db_column='Category', max_length=100)  # Field name made lowercase.
    subcategory = models.CharField(db_column='SubCategory', max_length=100, blank=True, null=True)  # Field name made lowercase.
    sortorder = models.IntegerField(db_column='SortOrder')  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)  # Field name made lowercase.
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventorycategory'


class BiInventorycountry(models.Model):
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    country = models.CharField(db_column='Country', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventorycountry'


class BiInventorygroups(models.Model):
    groupid = models.IntegerField(db_column='GroupID')  # Field name made lowercase.
    parentinventoryid = models.IntegerField(db_column='ParentInventoryID')  # Field name made lowercase.
    childinventoryid = models.IntegerField(db_column='ChildInventoryID')  # Field name made lowercase.
    quantity = models.IntegerField(db_column='Quantity', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventorygroups'


class BiInventoryprices(models.Model):
    priceid = models.IntegerField(db_column='PriceID')  # Field name made lowercase.
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    ranktypeid = models.IntegerField(db_column='RanktypeID')  # Field name made lowercase.
    pricetext = models.CharField(db_column='PriceText', max_length=25)  # Field name made lowercase.
    currencyid = models.IntegerField(db_column='CurrencyID')  # Field name made lowercase.
    price = models.DecimalField(db_column='Price', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume1 = models.DecimalField(db_column='Volume1', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume2 = models.DecimalField(db_column='Volume2', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume3 = models.DecimalField(db_column='Volume3', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume4 = models.DecimalField(db_column='Volume4', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice1 = models.DecimalField(db_column='OtherPrice1', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice2 = models.DecimalField(db_column='OtherPrice2', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice3 = models.DecimalField(db_column='OtherPrice3', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice4 = models.DecimalField(db_column='OtherPrice4', max_digits=19, decimal_places=4)  # Field name made lowercase.
    compare = models.DecimalField(db_column='Compare', max_digits=19, decimal_places=4)  # Field name made lowercase.
    taxableamount = models.DecimalField(db_column='TaxableAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    startdate = models.DateTimeField(db_column='StartDate')  # Field name made lowercase.
    enddate = models.DateTimeField(db_column='EndDate')  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)  # Field name made lowercase.
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.
    returnprice = models.DecimalField(db_column='ReturnPrice', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    mup_qtystart = models.IntegerField(db_column='MUP_QtyStart')  # Field name made lowercase.
    mup_qtystop = models.IntegerField(db_column='MUP_QtyStop')  # Field name made lowercase.
    mup_qtyvalue = models.IntegerField(db_column='MUP_QtyValue')  # Field name made lowercase.
    shippingvalue = models.DecimalField(db_column='ShippingValue', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    vattax = models.DecimalField(db_column='VATTax', max_digits=19, decimal_places=4)  # Field name made lowercase.
    handlingfee = models.DecimalField(db_column='HandlingFee', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventoryprices'


class BiInventorywarehouse(models.Model):
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    warehouseid = models.IntegerField(db_column='WarehouseID')  # Field name made lowercase.
    onhand = models.IntegerField(db_column='OnHand')  # Field name made lowercase.
    reorderpoint = models.IntegerField(db_column='ReOrderPoint', blank=True, null=True)  # Field name made lowercase.
    onhandshipped = models.IntegerField(db_column='OnHandShipped')  # Field name made lowercase.
    cost = models.DecimalField(db_column='Cost', max_digits=19, decimal_places=4)  # Field name made lowercase.
    idealonhand = models.IntegerField(db_column='IdealOnHand')  # Field name made lowercase.
    avgweightedcost = models.DecimalField(db_column='AvgWeightedCost', max_digits=19, decimal_places=4)  # Field name made lowercase.
    packslipsortorder = models.IntegerField(db_column='PackSlipSortOrder')  # Field name made lowercase.
    outofstocklevel = models.IntegerField(db_column='OutOfStockLevel')  # Field name made lowercase.
    outofstockmessage = models.CharField(db_column='OutOfStockMessage', max_length=300, blank=True, null=True)  # Field name made lowercase.
    lowstocklevel = models.IntegerField(db_column='LowStockLevel')  # Field name made lowercase.
    lowstockmessage = models.CharField(db_column='LowStockMessage', max_length=300, blank=True, null=True)  # Field name made lowercase.
    packslipproductid = models.CharField(db_column='PackslipProductID', max_length=40, blank=True, null=True)  # Field name made lowercase.
    packslipdescription = models.CharField(db_column='PackslipDescription', max_length=200, blank=True, null=True)  # Field name made lowercase.
    softcount = models.IntegerField(db_column='SoftCount')  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)  # Field name made lowercase.
    lastmodifiedby = models.CharField(db_column='LastModifiedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_inventorywarehouse'


class BiOrderdetails(models.Model):
    orderid = models.IntegerField(db_column='OrderID')  # Field name made lowercase.
    orderdetailid = models.IntegerField(db_column='OrderDetailID')  # Field name made lowercase.
    orderdetailstatusid = models.IntegerField(db_column='OrderDetailStatusID')  # Field name made lowercase.
    inventoryid = models.IntegerField(db_column='InventoryID')  # Field name made lowercase.
    groupitem = models.IntegerField(db_column='GroupItem')  # Field name made lowercase.
    groupownerdetailid = models.IntegerField(db_column='GroupOwnerDetailID')  # Field name made lowercase.
    packslipped = models.IntegerField(db_column='PackSlipped')  # Field name made lowercase.
    quantity = models.IntegerField(db_column='Quantity')  # Field name made lowercase.
    volume1 = models.DecimalField(db_column='Volume1', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume2 = models.DecimalField(db_column='Volume2', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume3 = models.DecimalField(db_column='Volume3', max_digits=19, decimal_places=4)  # Field name made lowercase.
    volume4 = models.DecimalField(db_column='Volume4', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice1 = models.DecimalField(db_column='OtherPrice1', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice2 = models.DecimalField(db_column='OtherPrice2', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice3 = models.DecimalField(db_column='OtherPrice3', max_digits=19, decimal_places=4)  # Field name made lowercase.
    otherprice4 = models.DecimalField(db_column='OtherPrice4', max_digits=19, decimal_places=4)  # Field name made lowercase.
    price = models.DecimalField(db_column='Price', max_digits=19, decimal_places=4)  # Field name made lowercase.
    tax = models.DecimalField(db_column='Tax', max_digits=19, decimal_places=4, blank=True, null=True)  # Field name made lowercase.
    taxableamount = models.DecimalField(db_column='TaxableAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    compare = models.DecimalField(db_column='Compare', max_digits=19, decimal_places=4)  # Field name made lowercase.
    trackingid = models.CharField(db_column='TrackingID', max_length=50, blank=True, null=True)  # Field name made lowercase.
    warehouseid = models.IntegerField(db_column='WarehouseID', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_orderdetails'


class BiOrderdetailstatuses(models.Model):
    orderdetailstatusid = models.IntegerField(db_column='OrderDetailStatusID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    official = models.SmallIntegerField(db_column='Official')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_orderdetailstatuses'


class BiOrders(models.Model):
    orderid = models.IntegerField(db_column='OrderID')  # Field name made lowercase.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    bcid = models.IntegerField(db_column='BCID')  # Field name made lowercase.
    customerid = models.IntegerField(db_column='CustomerID')  # Field name made lowercase.
    partyid = models.IntegerField(db_column='PartyID', blank=True, null=True)  # Field name made lowercase.
    orderdate = models.DateTimeField(db_column='OrderDate')  # Field name made lowercase.
    bonusdate = models.DateTimeField(db_column='BonusDate')  # Field name made lowercase.
    dateshipped = models.DateTimeField(db_column='DateShipped', blank=True, null=True)  # Field name made lowercase.
    orderstatusid = models.IntegerField(db_column='OrderStatusID')  # Field name made lowercase.
    rankpricetypeid = models.IntegerField(db_column='RankPriceTypeID')  # Field name made lowercase.
    shipping = models.DecimalField(db_column='Shipping', max_digits=19, decimal_places=4)  # Field name made lowercase.
    handling = models.DecimalField(db_column='Handling', max_digits=19, decimal_places=4)  # Field name made lowercase.
    shippingtax = models.DecimalField(db_column='ShippingTax', max_digits=19, decimal_places=4)  # Field name made lowercase.
    handlingtax = models.DecimalField(db_column='HandlingTax', max_digits=19, decimal_places=4)  # Field name made lowercase.
    totalprice = models.DecimalField(db_column='TotalPrice', max_digits=19, decimal_places=4)  # Field name made lowercase.
    currencytypeid = models.IntegerField(db_column='CurrencyTypeID', blank=True, null=True)  # Field name made lowercase.
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    dateposted = models.DateTimeField(db_column='DatePosted', blank=True, null=True)  # Field name made lowercase.
    market = models.TextField(db_column='Market', blank=True, null=True)  # Field name made lowercase.
    shipmethodid = models.IntegerField(db_column='ShipMethodID', blank=True, null=True)  # Field name made lowercase.
    order_type = models.TextField(db_column='Order Type')  # Field name made lowercase. Field renamed to remove unsuitable characters.
    orderlinkid = models.IntegerField(db_column='OrderLinkID', blank=True, null=True)  # Field name made lowercase.
    autoshipscheduleid = models.IntegerField(db_column='AutoShipScheduleID', blank=True, null=True)  # Field name made lowercase.
    autoshipbatchid = models.IntegerField(db_column='AutoshipBatchID', blank=True, null=True)  # Field name made lowercase.
    invoicenotes = models.CharField(db_column='InvoiceNotes', max_length=500, blank=True, null=True)  # Field name made lowercase.
    geocode = models.CharField(db_column='GeoCode', max_length=10, blank=True, null=True)  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_orders'


class BiOrderstatuses(models.Model):
    orderstatusid = models.IntegerField(db_column='OrderStatusID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=25)  # Field name made lowercase.
    official = models.SmallIntegerField(db_column='Official')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_orderstatuses'


class BiPayments(models.Model):
    paymentid = models.IntegerField(db_column='PaymentID')  # Field name made lowercase.
    paymenttypeid = models.IntegerField(db_column='PaymentTypeID')  # Field name made lowercase.
    paymentdate = models.DateTimeField(db_column='PaymentDate')  # Field name made lowercase.
    orderid = models.IntegerField(db_column='OrderID', blank=True, null=True)  # Field name made lowercase.
    amount = models.DecimalField(db_column='Amount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    paymentstatustypeid = models.SmallIntegerField(db_column='PaymentStatusTypeID')  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    createdby = models.CharField(db_column='CreatedBy', max_length=100, blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_payments'


class BiPaymentstatustypes(models.Model):
    paymentstatustypeid = models.SmallIntegerField(db_column='PaymentStatusTypeID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    official = models.SmallIntegerField(db_column='Official')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_paymentstatustypes'


class BiPaymenttypes(models.Model):
    paymenttypeid = models.IntegerField(db_column='PaymentTypeID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=25)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)  # Field name made lowercase.
    startdate = models.DateTimeField(db_column='StartDate', blank=True, null=True)  # Field name made lowercase.
    enddate = models.DateTimeField(db_column='EndDate', blank=True, null=True)  # Field name made lowercase.
    autoship = models.SmallIntegerField(db_column='Autoship', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_paymenttypes'


class BiPayoutdetails(models.Model):
    payoutdetailid = models.IntegerField(db_column='PayoutDetailID')  # Field name made lowercase.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')  # Field name made lowercase.
    prevbalanceforward = models.DecimalField(db_column='PrevBalanceForward', max_digits=19, decimal_places=4)  # Field name made lowercase.
    adjustments = models.DecimalField(db_column='Adjustments', max_digits=19, decimal_places=4)  # Field name made lowercase.
    bonusamount = models.DecimalField(db_column='BonusAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    preconversionamount = models.DecimalField(db_column='PreConversionAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    postconversionamount = models.DecimalField(db_column='PostConversionAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    balanceforward = models.DecimalField(db_column='BalanceForward', max_digits=19, decimal_places=4)  # Field name made lowercase.
    payoutfee = models.DecimalField(db_column='PayoutFee', max_digits=19, decimal_places=4)  # Field name made lowercase.
    reference_field = models.IntegerField(db_column='Reference #')  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    preconversioncurrencyid = models.IntegerField(db_column='PreConversionCurrencyID')  # Field name made lowercase.
    postconversioncurrencyid = models.IntegerField(db_column='PostConversionCurrencyID')  # Field name made lowercase.
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_payoutdetails'


class BiPayoutmethods(models.Model):
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    nextreferencenumber = models.IntegerField(db_column='NextReferenceNumber')  # Field name made lowercase.
    active = models.SmallIntegerField(db_column='Active')  # Field name made lowercase.
    minpayoutamount = models.DecimalField(db_column='MinPayoutAmount', max_digits=19, decimal_places=4)  # Field name made lowercase.
    processingfee = models.DecimalField(db_column='ProcessingFee', max_digits=19, decimal_places=4)  # Field name made lowercase.
    payoutmethodtype = models.CharField(db_column='PayoutMethodType', max_length=50)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_payoutmethods'


class BiPayoutprocesses(models.Model):
    payoutprocessid = models.IntegerField(db_column='PayoutProcessID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=250, blank=True, null=True)  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_payoutprocesses'


class BiQualificationagentdetails(models.Model):
    id = models.IntegerField(db_column='ID')  # Field name made lowercase.
    qualificationagentid = models.IntegerField(db_column='QualificationAgentID')  # Field name made lowercase.
    compqualprocessorcriteriaid = models.IntegerField(db_column='CompQualProcessorCriteriaID')  # Field name made lowercase.
    value = models.TextField(db_column='Value', blank=True, null=True)  # Field name made lowercase.
    criteriacompqualagentid = models.IntegerField(db_column='CriteriaCompQualAgentID', blank=True, null=True)  # Field name made lowercase.
    compoperatorid = models.SmallIntegerField(db_column='CompOperatorID', blank=True, null=True)  # Field name made lowercase.
    compositelevel = models.SmallIntegerField(db_column='CompositeLevel')  # Field name made lowercase.
    isoroperator = models.SmallIntegerField(db_column='IsOrOperator')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_qualificationagentdetails'


class BiQualificationagents(models.Model):
    qualificationagentid = models.IntegerField(db_column='QualificationAgentID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=200, blank=True, null=True)  # Field name made lowercase.
    configuration = models.CharField(db_column='Configuration', max_length=100, blank=True, null=True)  # Field name made lowercase.
    qualificationagent_groupid = models.IntegerField(db_column='QualificationAgent_GroupID', blank=True, null=True)  # Field name made lowercase.
    bonus_parameter = models.TextField(db_column='Bonus Parameter')  # Field name made lowercase. Field renamed to remove unsuitable characters.

    class Meta:
        managed = False
        db_table = 'bi_qualificationagents'


class BiQualificationagentvalues(models.Model):
    qualificationagentid = models.IntegerField(db_column='QualificationAgentID')  # Field name made lowercase.
    bonusrepid = models.BigIntegerField(db_column='BonusRepID')  # Field name made lowercase.
    value = models.FloatField(db_column='Value', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_qualificationagentvalues'


class BiRankpricetypes(models.Model):
    rankpricetypeid = models.IntegerField(db_column='RankPriceTypeID')  # Field name made lowercase.
    rankid = models.IntegerField(db_column='RankID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=25)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_rankpricetypes'


class BiRanks(models.Model):
    rankid = models.IntegerField(db_column='RankID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)  # Field name made lowercase.
    active = models.SmallIntegerField(db_column='Active')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_ranks'


class BiRepbonusdata(models.Model):
    bonusrepid = models.BigIntegerField(db_column='BonusRepID')  # Field name made lowercase.
    bonusrunid = models.IntegerField(db_column='BonusRunID')  # Field name made lowercase.
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    titlerankid = models.SmallIntegerField(db_column='TitleRankID')  # Field name made lowercase.
    bonusrankid = models.IntegerField(db_column='BonusRankID', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_repbonusdata'


class BiReps(models.Model):
    repid = models.IntegerField(db_column='RepID')  # Field name made lowercase.
    rep_field = models.CharField(db_column='Rep #', max_length=20)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    enrollerrepid = models.IntegerField(db_column='EnrollerRepID', blank=True, null=True)  # Field name made lowercase.
    uplinebcid = models.IntegerField(db_column='UplineBCID', blank=True, null=True)  # Field name made lowercase.
    bcposition = models.TextField(db_column='BCPosition', blank=True, null=True)  # Field name made lowercase.
    bcid = models.IntegerField(db_column='BCID')  # Field name made lowercase.
    bc_field = models.IntegerField(db_column='BC #', blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters. Field renamed because it ended with '_'.
    firstname = models.CharField(db_column='FirstName', max_length=50, blank=True, null=True)  # Field name made lowercase.
    lastname = models.CharField(db_column='LastName', max_length=50, blank=True, null=True)  # Field name made lowercase.
    middleinitial = models.CharField(db_column='MiddleInitial', max_length=1, blank=True, null=True)  # Field name made lowercase.
    joindate = models.DateTimeField(db_column='JoinDate')  # Field name made lowercase.
    email = models.CharField(db_column='Email', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstreet1 = models.CharField(db_column='BillStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstreet2 = models.CharField(db_column='BillStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcity = models.CharField(db_column='BillCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcounty = models.CharField(db_column='BillCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billstate = models.CharField(db_column='BillState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billpostalcode = models.CharField(db_column='BillPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    billcountry = models.CharField(db_column='BillCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet1 = models.CharField(db_column='ShipStreet1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstreet2 = models.CharField(db_column='ShipStreet2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcity = models.CharField(db_column='ShipCity', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcounty = models.CharField(db_column='ShipCounty', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipstate = models.CharField(db_column='ShipState', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shippostalcode = models.CharField(db_column='ShipPostalCode', max_length=50, blank=True, null=True)  # Field name made lowercase.
    shipcountry = models.CharField(db_column='ShipCountry', max_length=50, blank=True, null=True)  # Field name made lowercase.
    dateofbirth = models.DateTimeField(db_column='DateOfBirth', blank=True, null=True)  # Field name made lowercase.
    renewaldate = models.DateTimeField(db_column='RenewalDate')  # Field name made lowercase.
    payoutmethodid = models.IntegerField(db_column='PayoutMethodID', blank=True, null=True)  # Field name made lowercase.
    reptypeid = models.IntegerField(db_column='RepTypeID')  # Field name made lowercase.
    rankid = models.IntegerField(db_column='RankID')  # Field name made lowercase.
    date_cancelled = models.DateTimeField(db_column='Date Cancelled', blank=True, null=True)  # Field name made lowercase. Field renamed to remove unsuitable characters.
    taxid1 = models.CharField(db_column='TaxID1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    taxid2 = models.CharField(db_column='TaxID2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    taxexempt = models.SmallIntegerField(db_column='TaxExempt', blank=True, null=True)  # Field name made lowercase.
    phone1 = models.CharField(db_column='Phone1', max_length=50, blank=True, null=True)  # Field name made lowercase.
    phone2 = models.CharField(db_column='Phone2', max_length=50, blank=True, null=True)  # Field name made lowercase.
    phone3 = models.CharField(db_column='Phone3', max_length=50, blank=True, null=True)  # Field name made lowercase.
    phone4 = models.CharField(db_column='Phone4', max_length=50, blank=True, null=True)  # Field name made lowercase.
    phone5 = models.CharField(db_column='Phone5', max_length=50, blank=True, null=True)  # Field name made lowercase.
    phone6 = models.CharField(db_column='Phone6', max_length=50, blank=True, null=True)  # Field name made lowercase.
    preferredculture = models.IntegerField(db_column='PreferredCulture')  # Field name made lowercase.
    datecreated = models.DateTimeField(db_column='DateCreated')  # Field name made lowercase.
    datelastmodified = models.DateTimeField(db_column='DateLastModified', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_reps'


class BiReptypes(models.Model):
    reptypeid = models.IntegerField(db_column='RepTypeID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_reptypes'


class BiShipmethods(models.Model):
    shipmethodid = models.IntegerField(db_column='ShipMethodID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    abbreviation = models.CharField(db_column='Abbreviation', max_length=10, blank=True, null=True)  # Field name made lowercase.
    shipper = models.CharField(db_column='Shipper', max_length=50)  # Field name made lowercase.
    website = models.CharField(db_column='Website', max_length=100, blank=True, null=True)  # Field name made lowercase.
    trackingurl = models.CharField(db_column='TrackingURL', max_length=250, blank=True, null=True)  # Field name made lowercase.
    active = models.SmallIntegerField(db_column='Active')  # Field name made lowercase.
    multipleunit = models.CharField(db_column='MultipleUnit', max_length=50, blank=True, null=True)  # Field name made lowercase.
    web = models.SmallIntegerField(db_column='Web', blank=True, null=True)  # Field name made lowercase.
    priority = models.IntegerField(db_column='Priority')  # Field name made lowercase.
    immediate = models.SmallIntegerField(db_column='Immediate', blank=True, null=True)  # Field name made lowercase.
    surchargepercentage = models.DecimalField(db_column='SurchargePercentage', max_digits=18, decimal_places=8)  # Field name made lowercase.
    handlingfeeaware = models.SmallIntegerField(db_column='HandlingFeeAware')  # Field name made lowercase.
    surchargebase = models.DecimalField(db_column='SurchargeBase', max_digits=19, decimal_places=4)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_shipmethods'


class BiTaxcodes(models.Model):
    taxcodeid = models.CharField(db_column='TaxCodeID', max_length=25)  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=250, blank=True, null=True)  # Field name made lowercase.
    visibleonextranet = models.SmallIntegerField(db_column='VisibleOnExtranet', blank=True, null=True)  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_taxcodes'


class BiWarehouses(models.Model):
    warehouseid = models.IntegerField(db_column='WarehouseID')  # Field name made lowercase.
    description = models.CharField(db_column='Description', max_length=50)  # Field name made lowercase.
    packslipline1 = models.CharField(db_column='PackSlipLine1', max_length=100, blank=True, null=True)  # Field name made lowercase.
    packslipline2 = models.CharField(db_column='PackSlipLine2', max_length=100, blank=True, null=True)  # Field name made lowercase.
    packslipline3 = models.CharField(db_column='PackSlipLine3', max_length=100, blank=True, null=True)  # Field name made lowercase.
    packslipline4 = models.CharField(db_column='PackSlipLine4', max_length=100, blank=True, null=True)  # Field name made lowercase.
    packslipline5 = models.CharField(db_column='PackSlipLine5', max_length=100, blank=True, null=True)  # Field name made lowercase.
    packslipline6 = models.CharField(db_column='PackSlipLine6', max_length=100, blank=True, null=True)  # Field name made lowercase.
    active = models.SmallIntegerField(db_column='Active')  # Field name made lowercase.

    class Meta:
        managed = False
        db_table = 'bi_warehouses'


class MssubscriptionAgents(models.Model):
    id = models.IntegerField()
    publisher = models.CharField(max_length=128)
    publisher_db = models.CharField(max_length=128)
    publication = models.CharField(max_length=128)
    subscription_type = models.IntegerField()
    queue_id = models.CharField(max_length=128, blank=True, null=True)
    update_mode = models.SmallIntegerField()
    failover_mode = models.NullBooleanField()
    spid = models.IntegerField()
    login_time = models.DateTimeField()
    allow_subscription_copy = models.NullBooleanField()
    attach_state = models.IntegerField()
    attach_version = models.BinaryField()
    last_sync_status = models.IntegerField(blank=True, null=True)
    last_sync_summary = models.CharField(max_length=128, blank=True, null=True)
    last_sync_time = models.DateTimeField(blank=True, null=True)
    queue_server = models.CharField(max_length=128, blank=True, null=True)

    class Meta:
        managed = False
        db_table = 'mssubscription_agents'



from setuptools import setup, find_packages

setup(
    name="bydesign",
    version="1.0.9",
    author="Velocity Web Works",
    author_email="john@velocitywebworks.com",
    # url=""
    packages=find_packages(),
    install_requires=[
        'django',
    ],
    scripts=[],
    include_package_data=True,
    zip_safe=False,
)
